use std::sync::Arc;
use axum::routing::get;
use crate::handler;
use crate::state::AppState;

pub fn init() -> axum::Router<Arc<AppState>> {
    let category_router = axum::Router::new()
        .route("/", get(handler::category::index))
        .route(
            "/add",
            get(handler::category::add_ui).post(handler::category::add),
        )
        .route(
            "/edit/:id",
            get(handler::category::edit_ui).post(handler::category::edit),
        )
        .route("/del/:id", get(handler::category::del))
        .route("/del/:id/:real", get(handler::category::del))
        .route("/articles/:id", get(handler::category::articles));

    let article_router = axum::Router::new()
        .route("/", get(handler::article::index))
        .route("/add", get(handler::article::add_ui).post(handler::article::add))
        .route("/tags", get(handler::article::list_with_tags));

    axum::Router::new()
        .route("/", get(handler::index))
        .nest("/category", category_router)
        .nest("/article", article_router)
}
